/*************************************************************************************
  Envoi Température et Humidité toute les 3 minutes
  par J.C 18/11/2021
**************************************************************************************/
#include <Adafruit_Sensor.h>
#include <DHT.h>
#include <DHT_U.h>
#define DHTPIN 2
#define DHTTYPE    DHT22     // DHT 22 (AM2302)
DHT_Unified dht(DHTPIN, DHTTYPE);

#include <MKRWAN.h>
LoRaModem modem;

//#include "ArduinoLowPower.h"

// ********** Déclaration des identifiant TTN *************
#include "arduino_secrets.h"
// Ces identifiants sont indiqués dans arduino_secrets.h
String appEui = SECRET_APP_EUI;
String appKey = SECRET_APP_KEY;

// ***************** Configuration ************************
void setup() {
  Serial.begin(115200);
  dht.begin();
  //while (!Serial);  // Blocage tant que le moniteur série n'est pas ouvert
  delay(2000);
  // -- Connexion au module LoRa intégré --
  if (!modem.begin(EU868)) {    // à adapter en fonction de la fréquence de la zone (eg. US915, AS923, ...)
    Serial.println("Pb avec le module LoRa !");
    while (1) {}
  };
  Serial.print("La version du module est: ");
  Serial.println(modem.version());
  Serial.print("Le device EUI est: ");
  Serial.println(modem.deviceEUI());

  // -- Tentative de connexion à une passerelle LoRa --
  int connected = modem.joinOTAA(appEui, appKey);
  if (!connected) {
    Serial.println("Pb pour atteindre une gateway LoRa. Déplacez-vous pour être dans la zone de réception d'une gateway.");
    while (1) {} // Blocage du programme si pas de passerelle trouvée
  }

  // Définition de l'intervalle d'envoi minimum ... mais apparemment le firmware impose une limitation à 1 message maximum toutes les 2 minutes, ceci afin de respecter la philisophie de LoRa
  // Mais apparemment il n'y a plus cette limitation avec les derniers MKR (mars 2021) ? A vérifier.
  modem.minPollInterval(60);
  Serial.println();
}


// ******************** Programme principal ***********************
void loop()
{
  float t,h;
  sensors_event_t event;
  dht.temperature().getEvent(&event);
  if (isnan(event.temperature)) {
    Serial.println(F("Error reading temperature!"));
  }
  else {
    Serial.print(F("Temperature: "));
    t=event.temperature;
    Serial.print(t);
    Serial.println(F("°C"));
  }
  dht.humidity().getEvent(&event);
  if (isnan(event.relative_humidity)) {
    Serial.println(F("Error reading humidity!"));
  }
  else {
    Serial.print(F("Humidity: "));
    h=event.relative_humidity;
    Serial.print(h);
    Serial.println(F("%"));
  }

  String messageDeBase = String(t)+";"+String(h);

  // Affichage du message à envoyer dans la console pour contrôle
  Serial.print(messageDeBase);
  Serial.println();

  // Transmission du message via LoRa
  int err;
  modem.beginPacket();                                // Démarrage du modem LoRa
  modem.print(messageDeBase);                                   // Envoi du message
  err = modem.endPacket(true);                        // Renvoi le message d'erreur de transmission (>0 si pas de problème). Un envoi trop fréquent (plus fréquen que 2') provoque une erreur.
  if (err > 0) {
    Serial.println("Message envoyé.");
  } else {
    Serial.println("Erreur lors de l'envoi :(");
  }
  Serial.println();
  // s'endormir
  //LowPower.sleep(10000);
  delay(120000);

}
